facet_unwrap.RdUseful when there are a lot of panels and you want to browse (and optionally save) them one by one
facet_unwrap(g, plot = TRUE, save = FALSE, path = ".", ...)the ggplot2 object created as normal
whether to plot (or just save by turn the next args to TRUE)
whether to save the plot to disk
where to save them?
Arguments passed on to ggplot2::ggsave
filenameFile name to create on disk.
deviceDevice to use. Can either be a device function
(e.g. png), or one of "eps", "ps", "tex" (pictex),
"pdf", "jpeg", "tiff", "png", "bmp", "svg" or "wmf" (windows only). If
NULL (default), the device is guessed based on the filename extension.
scaleMultiplicative scaling factor.
width,heightPlot size in units expressed by the units argument.
If not supplied, uses the size of the current graphics device.
unitsOne of the following units in which the width and height
arguments are expressed: "in", "cm", "mm" or "px".
dpiPlot resolution. Also accepts a string input: "retina" (320), "print" (300), or "screen" (72). Only applies when converting pixel units, as is typical for raster output types.
limitsizeWhen TRUE (the default), ggsave() will not
save images larger than 50x50 inches, to prevent the common error of
specifying dimensions in pixels.
bgBackground colour. If NULL, uses the plot.background fill value
from the plot theme.
create.dirWhether to create new directories if a non-existing
directory is specified in the filename or path (TRUE) or return an
error (FALSE, default). If FALSE and run in an interactive session,
a prompt will appear asking to create a new directory when necessary.
invisible a list of ggplot objects, one for each panels
if (FALSE) { # \dontrun{
g <- iris %>%
ggplot(aes(Sepal.Length)) +
geom_histogram() +
facet_wrap(~Species)
facet_unwrap(g)
} # }